/***
 * Cecilia ADL Compiler
 * Copyright (C) 2006-2007 STMicroelectronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: fractal@objectweb.org
 *
 * Author:Ali Erdem Ozcan
 */

package org.objectweb.fractal.cecilia.adl.idl.ast;

/**
 * AST node interface for <code>primitiveType</code> elements.
 */
public interface PrimitiveType extends Type {

  /** Enumeration of the primitive types. */
  public static enum PrimitiveTypeEnum {
    /** The name of the any primitive type. */
    ANY,

    /** The name of the void primitive type. */
    VOID,

    /** The name of the boolean primitive type. */
    BOOLEAN,

    /** The name of the char primitive type. */
    CHAR,

    /** The name of the byte primitive type. */
    BYTE,

    /** The name of the short primitive type. */
    SHORT,

    /** The name of the int primitive type. */
    INT,

    /** The name of the long primitive type. */
    LONG,

    /** The name of the float primitive type. */
    FLOAT,

    /** The name of the double primitive type. */
    DOUBLE,

    /** The name of the string primitive type. */
    STRING,

    /** The name of the unsigned byte primitive type. */
    UNSIGNED_BYTE,

    /** The name of the unsigned short primitive type. */
    UNSIGNED_SHORT,

    /** The name of the unsigned int primitive type. */
    UNSIGNED_INT,

    /** The name of the unsigned long primitive type. */
    UNSIGNED_LONG
  };

  /**
   * Returns the name of the primitive type.
   * 
   * @return the name of the primitive type.
   */
  String getName();

  /**
   * Set the name of the primitive type.
   * 
   * @param name the name of the primitive type to be set.
   */
  void setName(String name);
}
